@@ -7,7 +7,7 @@ from xpycommon.log import Logger, DEBUG
 from btl2cap import PSMs
 
 from btsdp import DataElement, DataElementTypes, UUID_L2CAP
-from btsdp.fuzzer import SdpServerFuzzer
+from btsdp.fuzz import SdpServerFuzzer
 
 
 logger = Logger(__name__, DEBUG)
